# Cutting Google out of your life *(Updated: May 2020)*

### *I don't have anything to hide, but I don't have anything to show you either.*

# Index

1. [Contributing](#contributing)
2. [Browser extensions](#browser-extensions)
3. **[Replacements/alternatives](#replacementsalternatives)**
    1. [Disclaimer](#disclaimer)
    2. [Web-based products](#web-based-products)
    3. [Operating systems](#operating-systems)
    4. [Desktop applications](#desktop-applications)
    5. [Mobile applications](#mobile-applications-mobile-apps-installable-from-stores)
    6. [Hardware](#hardware)
4. [Useful links, tools, and advice](#useful-links-tools-and-advice)
    1. [Resources](#resources)
    1. [Books](#books)
    1. [Blog posts](#blog-posts)
    1. [News articles](#news-articles)
5. [The lighter side](#the-lighter-side)
6. [Closing remarks](#closing-remarks)

# Contributing

If you want to help out with the project, here are some ideas (submit **Issues** & **Pull Requests** on the [GitHub page](https://github.com/tycrek/degoogle)):

- **iOS app alternatives!** I don't have an iOS device to find alternatives with. I would highly appreciate any help with this.
- Clean up/improve the Markdown.
- Provide more information on services with little info or where *help requested!* is shown.
- Suggest new services or provide info for removing existing services.
- Host a mirror or clone the [repo](https://github.com/tycrek/degoogle). If you host a mirror, let me know and I can add it to the mirrors list.
- Anything else relating to any part of this guide, whether it's Google related or not.

When contributing, **please try to follow the rules outlined in [CONTRIBUTING.md](https://github.com/tycrek/degoogle/blob/master/CONTRIBUTING.md)**.

# Browser extensions

These Firefox extensions can help prevent connections to Google domains and also improve your privacy/security online.

- [uBlock Origin](https://addons.mozilla.org/en-US/firefox/addon/ublock-origin/)
- [Privacy Badger](https://addons.mozilla.org/en-US/firefox/addon/privacy-badger17/)
- [Decentraleyes](https://addons.mozilla.org/en-US/firefox/addon/decentraleyes/)
- [HTTPS Everywhere](https://addons.mozilla.org/en-US/firefox/addon/https-everywhere/)
- [Cookie AutoDelete](https://addons.mozilla.org/en-US/firefox/addon/cookie-autodelete/)
- [DDG Privacy Essentials](https://addons.mozilla.org/en-US/firefox/addon/duckduckgo-for-firefox/)
- [I don't care about cookies](https://addons.mozilla.org/en-US/firefox/addon/i-dont-care-about-cookies/)
- [minerBlock](https://addons.mozilla.org/en-US/firefox/addon/minerblock-origin/)
- [Terms of Service; Didn't Read](https://addons.mozilla.org/en-US/firefox/addon/terms-of-service-didnt-read/)
- An expanded list from u/R0B0LUT10N:
  - [ClearURLS](https://addons.mozilla.org/en-US/firefox/addon/clearurls/)
  - [Cloud Firewall](https://addons.mozilla.org/en-US/firefox/addon/cloud-firewall/)
  - [CSS Exfil Protection](https://addons.mozilla.org/en-US/firefox/addon/css-exfil-protection/)
  - [Disconnect](https://addons.mozilla.org/en-US/firefox/addon/disconnect/)
  - [Don't touch my tabs! (rel=noopener)](https://addons.mozilla.org/en-US/firefox/addon/dont-touch-my-tabs/)
  - [Firefox Multi-Account Containers](https://addons.mozilla.org/en-US/firefox/addon/multi-account-containers/)
  - [Google search link fix (also Yandex)](https://addons.mozilla.org/en-US/firefox/addon/google-search-link-fix/)
  - [HTTPZ](https://addons.mozilla.org/en-US/firefox/addon/httpz/)
  - [Link Cleaner](https://addons.mozilla.org/en-US/firefox/addon/link-cleaner/)
  - [Neat URL](https://addons.mozilla.org/en-US/firefox/addon/neat-url/)
  - [Privacy-Oriented Origin Policy](https://addons.mozilla.org/en-US/firefox/addon/privacy-oriented-origin-policy/)
  - [Skip Redirect](https://addons.mozilla.org/en-US/firefox/addon/skip-redirect/)
  - [Temporary Containers](https://addons.mozilla.org/en-US/firefox/addon/temporary-containers/)
- [uMatrix](https://addons.mozilla.org/en-US/firefox/addon/umatrix/) (thanks u/rudolf323)
- [TrackMeNot](https://addons.mozilla.org/en-US/firefox/addon/trackmenot/)

# Replacements/alternatives

### *Disclaimer*

1. Only **privacy/security** focused alternatives will be suggested.
2. Many replacements are based off [this Wikipedia article (List of Google products)](https://en.wikipedia.org/wiki/List_of_Google_products)
3. Products from companies such as Microsoft, Apple, Yahoo, Amazon, etc. will *not* be recommended unless there is a very good reason to. This includes companies/apps/services they own.
4. Controversial services will have a disclaimer attached if needed.
5. 5-eyes, 9-eyes, and 14-eyes services **will** be listed, and marked as such. This means the company, not the server IP.
    - **5**: Australia, Canada, New Zealand, UK, USA
    - **9**: Denmark, France, Netherlands, Norway
    - **14**: Germany, Belgium, Italy, Sweden, Spain
    - [What are 5-eyes, 9-eyes, and 14-eyes?](https://restoreprivacy.com/5-eyes-9-eyes-14-eyes/)

## Web-based products

- Search (web, images)

  | Name | Eyes | Description |
  | ---- | ---- | ----------- |
  | [DuckDuckGo](https://duckduckgo.com/) | **5-eyes** | One of the best privacy-focused search engines. Domain is hosted in USA which could potentially be problematic for some. |
  | [Startpage](https://www.startpage.com/) | **9-eyes** | Another privacy search engine that claims to not track any of your data. They operate servers in both USA and Europe. Note: Startpage was recently acquired. See [Issue #12](https://github.com/tycrek/degoogle/issues/12). Thanks @pydo, @ThijsRay, and @DatAres37. Also see [this comment in Issue #99](https://github.com/tycrek/degoogle/issues/99#issuecomment-616224650) from @danarel on Startpage. |
  | [searx.me](https://searx.me/) | | [Open-source](https://github.com/asciimoo/searx) (thanks for clarification u/Sheezdudeln) privacy search engine. Domain hosted in Germany. |
  | [MetaGer](https://metager.org/about) | **14-eyes** | MetaGer is the search engine project from the registered nonprofit organization SUMA E.V. in Germany. |
  | [Qwant](https://www.qwant.com/) | **9-eyes** | Major improvements since 2018's guide. *would prefer better info other than an outdated reference* |
  | [Swisscows](https://swisscows.ch/) | | A Swiss search engine that offers a unique search experience for the web, images, videos, music, and more. They are currently funding a mail service. Read through their [datacenter](https://swisscows.ch/en/datacenter) about page, it's really interesting. |
  | [Mojeek](https://www.mojeek.com/) | **5-eyes** | Unlike other privacy search engines which act as a "middle man" between you and Google/Bing/Yahoo, Mojeek has their own crawler and index. The results aren't as complete as some of the others, but it is still impressive and they are actively building their index to include more results with better accuracy. |
  | [Ekoru](https://ekoru.org/) | | Privacy focused search engine that also aims to clean up the oceans. Thanks @mynamesleon |
  | [Cyberd](https://cyber.page/) | | Decentralized Google. A web 3 alternative for the Google search engine. In Beta testing mode. Uses IPFS and Tendermint consensus for security and economic incentives. Please see their [ELI-5 FAQ](https://github.com/cybercongress/congress/blob/master/ecosystem/ELI-5%20FAQ.md) for more info. |
  | [Infinity Search](https://infinitysearch.co/) | **5-eyes** | Infinity Search is a privacy metasearch engine that does not log any information about its users. In terms of privacy, it works the same way as DuckDuckGo. It is free to use and is funded by non-tracking advertisements and affiliate links. It is also completely open source. |

- Images
  - *See above. All provide some form of image search.*
- YouTube
  - [PeerTube](https://joinpeertube.org/en/) - Decentralized video hosting network. Still quite small, but is growing and has a dedicated community.
  - [BitChute](https://www.bitchute.com/) - **5-eyes** - Also P2P, but not decentralized. Due to it being proprietary, if BitChute goes down then the whole thing goes down (unlike PeerTube). (thanks u/up-sky-7)
  - [DTube](https://d.tube/) - Looks very similar to YouTube. Advertised as "first crypt-decentralized video-platform". Built on Steemit and IPFS.
  - [Bit.tube](https://bit.tube/) - Appears to be a crypto-powered decentralized video sharing service. (thanks u/rudolf323)
  - [Invidious](https://invidio.us/) - An [open-source](https://github.com/omarroth/invidious) front-end alternative to YouTube. Seems to work pretty well from my experience so far, and it hasn't triggered *anything* on my adblocker/privacy extensions. Also offers downloads in many formats for videos (including `.vtt` subtitles).
  - [Hooktube](https://hooktube.com/) - A slightly better way to use actual YouTube. (Use as a "last resort")
  - [LBRY](https://lbry.com/) - A decentralized platform for distributing and supporting creators's work. It aims to be Open, Community driven "digital marketplace". It can be used in a similar way to YouTube: browsing, subscribing to channels, there is a mechanism to send "tips" to creators. Looks up videos based on a blockchain and is open source and uncensored. It already has some "larger" creators like Minutephysics, Veritasium, Barnacules and Lunduke.
  - [US.TV](https://us.tv/) - PeerTube instance hosted by Epik.com.
- News
  - [Subscribe to a (local) newspaper](https://en.wikipedia.org/wiki/Category:Lists_of_newspapers_by_country) and support independent and qualitative journalism.
  - Removed Reddit news as they are typically *extremely* biased to the general populace.
  - [AllSides](https://www.allsides.com/unbiased-balanced-news) - Seemingly unbiased news source. Thanks @jeanofthedead
  - Use good old-fashioned RSS feeds: Try [Feeder](https://f-droid.org/app/com.nononsenseapps.feeder) for Android (available from F-Droid)
  - *Help requested!*
- Groups
  - *Use other forum sites relating to specific topics. This is a very broad service.*
- Translate
  - [DeepL](https://deepl.com/) - **14-eyes** - DeepL is an artifical intelligence translation service. *Editor note: The site server seems to be hosted in Finland, yet the company lists itself as [a company based in Germany](https://www.deepl.com/pro-faq.html) in the Data Protection section.*
  - *Help requested!*
- Google Ads/AdMob/AdSense
  - [CodeFund](https://codefund.io/) -- **5-eyes** - ethical advertising for technical audience.
  - *Help requested!*
- Google Alerts
  - [F5Bot](https://f5bot.com/) - **5-eyes** - emails you when your selected keywords are mentioned on Reddit, Hacker News, or Lobsters.
  - *Help requested!*
- G Suite
  - [Zoho](https://www.zoho.com/) - Zoho was included in 2018's thread as well, and they've only improved since then. They offer a full enterprise business suite that can easily rival G Suite or MS Office 365.
  - [Nextcloud](https://www.nextcloud.com/) & [ONLYOFFICE](https://www.onlyoffice.com/) - Nextcloud 18 now has Community Document Server and OnlyOffice apps integrated which allows self hosted instances of docs/sheets/slides. Users are able to edit documents in real time. Thanks @k3tan172 and @plutocrat
  - Offline-only alternates are listed below
- Blogger/Sites
  - [Joomla](https://www.joomla.org/) - Self-hosted and open-source content management system (CMS).
  - [Write.as](https://write.as/) - Self-advertised as privacy-focused.
  - [WordPress](https://wordpress.org/) self-hosted - The open-source version of WordPress. A very popular tool and a recognized name.
  - [concrete5](https://www.concrete5.org/about) - **5-eyes** - Open-source CMS.
  - [Noblogs](https://noblogs.org/) - **9-eyes** - A privacy/security focused blogging platform.
  - [Ghost](https://ghost.org/) - Open-source modern CMS. Boasts "over 19x faster than WordPress". Thanks @peterge1998
- Analytics
  - [Matomo](https://matomo.org/) - **9/14-eyes** (Matomo/parent company) - Open-source analytics platform. (thanks u/Newblik)
  - [Fathom](https://usefathom.com/) - **5-eyes** - Simple analytics for bloggers & businesses
  - [Plausible](https://plausible.io/) - **5-eyes** - Open-source, privacy-focused web analytics.
  - [GoatCounter](https://www.goatcounter.com/) - **14-eyes** - Simple web statistics. No tracking of personal data. Open-source and may be self-hosted. Free for non-commercial use; paid plans available.
  - [Simple Analytics](https://simpleanalytics.com/) - **9-eyes** - Great analytics with privacy and simplicity in mind. Paid plans only (with free trials).
  - [Toasted Analytics](https://toastedanalytics.com/) - **5-eyes** -  Simple, privacy friendly analytics with event tracking. Paid only (with free trial)
- Photos
  - [Photoprism](https://github.com/photoprism/photoprism) - Self-hosted and open-source Personal Photo Management powered by Go and Google TensorFlow.
  - [ownPhotos](https://github.com/hooram/ownphotos) - Self-hosted and open-source Google Photos alternative.
  - [Piwigo](https://piwigo.org/) - **9-eyes** (self-hosted) - Self-hosted and open-source cloud photo manager. You can also sign up for an ["as a service" account](https://piwigo.com).
  - [JottaCloud](https://jottacloud.com/en/) - **9-eyes** - Norway based cloud storage provider with free and paid plans. Thanks @mynamesleon
- Calendar
  - [Lightning Calendar](https://www.thunderbird.net/en-US/calendar/) (Thunderbird)- Developed by Mozilla Foundation and open-source. Integrates into Thunderbird and SeaMonkey.
  - [Tutanota Calendar](https://tutanota.com/calendar/) - **14-eyes** - Developed by Tutanota. Free cross-platform encrypted calendar. Allows importing of other Calendar files. Can't be synced to other calendar software.
  - [Fruux](https://fruux.com/) - **14-eyes** - Open-source calendar using "sabre/dav" (open-source WebDAV, CardDAV, and CalDAV). They mention privacy quite a bit on their site. Very large number of features, and supports nearly every device: Windows, iOS, Linux, Android, BlackBerry, SailFish, and also a webapp for browsers.
  - [Zoho](https://www.zoho.com/) - I mentioned Zoho above for G Suite, so here they are again.
  - [EteSync](https://www.etesync.com) - Secure, end-to-end encrypted, and open-source sync for your contacts, calendars and tasks.
- Docs/Sheets/Slides (cloud)
  - [CryptPad](https://cryptpad.fr/) - **9-eyes** - Open-source "zero knowledge" collaborative cloud editor. They offer Rich Text, Code, Presentation, Sheet (beta), Poll, Kanban, Whiteboard, and CryptDrive. 100% Client side encryption. Tons of useful features.
  - [Etherpad](https://etherpad.org/) - Self-hosted collaborative editor. Does not use the browser. Not the greatest interface, but it's open-source and you have full control over who can see your data.
  - [Cryptee](https://crypt.ee/) - Open-source and privacy focused photo and document storage/editing. Based in Estonia, so your files are outside the reach of any 14-eyes country. They don't even require an email address to sign up.
  - [LibreOffice Online](https://www.libreoffice.org/download/libreoffice-online/) - **14-eyes** - Self-hosted instance of LibreOffice that you can run in your browser. Thanks @flubberding
  - [ONLYOFFICE](https://www.onlyoffice.com) - Open-source private cloud replacement for Google Docs'suite and Office 360. Also available as a self contained rich application.
  - [Arcane Office](https://arcaneoffice.com/) - A decentralized office suite with high-security and zero-knowledge on your data. With Arcane Office, you have maximum control on your personal stuff. Full-featured online document and spreadsheet editor. Secure storage to save your photos. All free for personal use. Thanks @taraletti
- Docs/Sheets/Slides (offline)
  - [LibreOffice](https://www.libreoffice.org/) and [Apache OpenOffice](https://www.openoffice.org/) - **14-eyes** - Both are open-source offline document suites.
  - [LyX](https://www.lyx.org/) - It's an open-source (and offline) document processor using TeX/LaTeX. It's different than Docs or Word but amazing, once you get used to it. Thanks @Glitchy-Tozier
- Domains
  - [Njalla](https://njal.la/) - **14-eyes** - Privacy-focused domain registration. Competitive pricing and a large list of available domain extensions. They also offer VPS hosting. Built by people who built The Pirate Bay among others. (thanks u/brais33 and u/HumbleBasis6)
  - [Porkbun](https://porkbun.com/) - **5-eyes** - Domain registration with free WHOIS privacy.
- Drive
  - [ownCloud](https://owncloud.org/) - Open-source and self-hosted. Provide your own storage.
  - [Nextcloud](https://nextcloud.com/) - Also self-hosted. Spin-off of ownCloud. **Also offers Calendar and Contacts** (thanks @chribre)
  - [Syncthing](https://syncthing.net/) - **9-eyes** - An interesting take on cloud storage: decentralized. Peer-to-peer between only your devices. Software is open-source and available on GitHub.
  - [Sia](https://sia.tech/) - Fully decentralized cloud storage.
  - [Tresorit](https://tresorit.com/) - Primarily meant for businesses, but offers a free version for individuals as well. (thanks u/xNick26)
  - [Sync](https://www.sync.com) - End-to-end encrypted Google Drive/Dropbox replacement.
  - [JottaCloud](https://jottacloud.com/en/) - **9-eyes** - Norway based cloud storage provider with free and paid plans. Thanks @mynamesleon
  - [Armored](https://armored.net/) - **9-eyes** - Nextcloud instance hosted by Epik.com. Paid plans with 30-day trial. Servers in a "secure bunker" in Norway. Supports other Nextcloud features such as Nextcloud Talk.
  - [seafile](https://www.seafile.com) - Open-source and self-hosted file sync&share solution.
  - [Cozy Cloud](https://cozy.io/) - **9-eyes** - French based cloud storage provider with free and paid plans. Can also be self-hosted. Open-Source. And it also offers a collaborative notes editor.
  - *Editor note: I'm not including MEGA. I do not recommend MEGA. It's far too controversial and far too difficult to figure out who actually owns the service. Also, it's a 5-eyes.*
- Hangouts (text/video messaging)
  - [Signal](https://signal.org/) - **5-eyes** - Whistleblower and privacy advocate Edward Snowden recommends Signal.
  - [Tox](https://tox.chat/) - Tox is unique as it uses P2P technology to ensure the network *never* goes down, as long as there are users to keep it alive. They specifically say on the website "Tox has no central servers that can be raided, shut down, or forced to turn over data".
  - [Wire](https://wire.com/en/) - **5-eyes** - Uses end-to-end encryption. Looks to be more of a corporate service with tiered plans.
  - [Riot](https://about.riot.im/) - **5-eyes** - Open-source privacy-focused chat service with end-to-end encryption. They offer webapps, desktop apps, iOS, and Android (Play Store and F-Droid). Uses the "Matrix" protocol for decentralized communication. It is 100% free and open-source with no paid plans.
  - [Threema](https://threema.ch/en) - Swiss-based GDPR-compliant instant messenger. Has apps for both iOS and Android. Unlike Signal, no phone number is required (nor is an email) to sign up. End-to-end encrypted. Thanks to @nathanvogel
  - [Keybase](https://keybase.io/) - **5-eyes** - encrypted chat like Signal with features like Slack. Does not require a phone number to sign up. Also has file storage. **Note:** Keybase was acquired by Zoom, Inc. in May 2020 ([Keybase blog](https://keybase.io/blog/keybase-joins-zoom), [Zoom blog](https://blog.zoom.us/wordpress/2020/05/07/zoom-acquires-keybase-and-announces-goal-of-developing-the-most-broadly-used-enterprise-end-to-end-encryption-offering/)). Thanks @notpushkin & @multimob.
  - [Jitsi](https://jitsi.org/) - Jitsi is an open-source secure video conferencing platform. No account is needed to use it, simply enter a Room Name to join or host a meeting. The host is able to kick rogue users from the call. Works directly in your browser, with apps available for iOS and Android. It is not necessary to self-host, but self-hosting is an option for those who wish to. Very low latency and easy to set up. A free public server is available at (https://meet.jit.si) (**5-eyes** server)
  - *Editor note: See [this article](https://outline.com/BK8f7h) for why I didn't include WhatsApp and why you should NOT use it (if someone has a better Outline link, that would be much appreciated).*
  - I have also **removed** Telegram. See [Issue #29](https://github.com/tycrek/degoogle/issues/29) from @arsv.
- Gmail
  - [Protonmail](https://protonmail.com/) - One of the top privacy-focused email providers. Servers are in Switzerland in an underground guarded bunker that they claim can "survive a nuclear attack".
  - [Zoho Mail](https://www.zoho.com/mail/) - Zoho comes back yet again with a mail solution.
  - [Tutanota](https://tutanota.com/) - **14-eyes** - Open-source. Also one of the top privacy-focused email providers. Located in Germany.
  - [Posteo](https://posteo.de/en) - **14-eyes** - Completely anonymous mail provider located in Germany.
  - [mailbox.org](https://mailbox.org/en/) - **14-eyes** - Paid email provider, also located in Germany.
  - [Disroot](https://disroot.org/) - **9-eyes** - Decentralized email service.
  - [StartMail](https://www.startmail.com/en/) - **9-eyes** - Operated by the same people who run StartPage.
  - [SimpleLogin](https://simplelogin.io/) - Open-source, self-hosted, and privacy focused email forwarding service.
  - [Migadu](https://www.migadu.com/en/index.html) - Paid email provider, located in Switzerland. Focus on privacy.
  - [FastMail](https://fastmail.com/) - **5-eyes** - Paid email provider, located in Australia and US.
  - [Runbox](https://runbox.com/why-runbox/privacy-protection/) - **9-eyes** - Privacy focusued email provider. Thanks @petertorelli
  - [nextCloud](https://help.nextcloud.com/t/nextcloud-mail-server/157) - Now also provides an email service (self-hosted). Thanks @je-vv
  - [Anonymize.com Email](https://anonymize.com/) - Paid secure email service provided by Epik.com.
  - *This is just for the Gmail service, not a client*
- Keep
  - [Joplin](https://joplinapp.org/) - Open-source notes/todo app. Available for Windows, macOS, Linux, Android, and iOS. Also offers a terminal version. It can import Evernote `.enex` files if you use that. It can also sync with Nextcloud (mentioned above).
  - [Standard Notes](https://standardnotes.org/) - Encrypted note storage with loads of features. Offers a web app as well as downloads for most operating systems. Has a paid plan, but the free tier has many useful features as well.
  - [Zoho Notebook](https://www.zoho.com/notebook/) - A notebook from Zoho. Also available on Android.
  - [Turtl](https://turtlapp.com/) - Encrypted collaborative notebook with possibility of running your own server.
  - [QOwnNotes](https://www.qownnotes.org/) - Open-source file editor with Markdown support. (thanks u/maqp2)
  - [EteSync](https://www.etesync.com) - Secure, end-to-end encrypted, and open-source sync for your contacts, calendars and tasks.
  - [GitJournal](https://gitjournal.io/) - Your Markdown notes stores in any Git Repo. Available for both Android (Play Store) and iOS.
- Play Music & Play Movies and TV
  - [Jellyfin](https://jellyfin.github.io/) - Open-source alternative to the Play media services. You do need to provide your own content, however. In active development with frequent updates (to the source, that is).
  - [Funkwhale](https://funkwhale.audio/) - Self-hosted, decentralized music service. Provide your own audio. (thanks u/DashEquals)
  - [Airsonic](https://airsonic.github.io/) - **Music only** - Self-hosted open-source media streamer. Has features for transcoding audio on-the-fly for "virtually any audio format". You can also set bandwidth limits if you need to. Looks very powerful.
  - [Music Player Daemon](https://www.musicpd.org/) - A "flexible, powerful, server-side application for playing music".
  - [Popcorn Time](https://popcorntime.sh/faq) - Open source software for desktop and mobile that let you easily stream movie/TV torrents. **Be careful if your country or ISP has policies against torrenting, a VPN is recommended.** Thanks @je-vv
  - [Nuclear Music Player](https://nuclear.js.org/) - Streaming music player that finds music from free sources automatically.
  - *Editor note: I can no longer recommend [Emby](https://emby.media/) as they are [no longer open-source](https://www.linuxuprising.com/2018/12/jellyfin-free-software-emby-media.html).*
  - Thanks to u/eA8KESARaW6iqCpHsbE4 for suggesting Jellyfin and pointing out that Emby isn't open-source.
- Fonts
  - [Open Font Library](https://fontlibrary.org/) - **5-eyes** - Lots of Serif and Sans-Serif fonts that can be directly embedded into a website.
  - [google webfonts helper](https://google-webfonts-helper.herokuapp.com/fonts) - **5-eyes** - Hassle-free way for webmasters to self-host open-source Fonts from "Google Fonts"
- Classroom
  - [Moodle](https://moodle.org/) - Self-hosted Classroom software for schools. Very powerful. Thanks @jankapunkt
  - [ILIAS](https://www.ilias.de/en/) - Another self-hosted open source classroom software. Thanks again to @jankapunkt
  - [Canvas](https://www.instructure.com/canvas) Paid service by Instructure. Also available as a [self-hosted, open source option](https://github.com/instructure/canvas-lms). To ensure privacy, use the self-hosted option.
- Maps/Street View
  - [OpenStreetMap](https://www.openstreetmap.org/) **9-eyes** - Collaborative project to create a free, editable map of the world (from Wikipedia). Completely crowdsourced. Very strong alternative to Maps.
  - [Qwant Maps](https://www.qwant.com/maps/) - Maps from the makers of Qwant search engine. Thanks @mynamesleon
  - [Benmaps](https://benmaps.fr) - Another maps alternative based on OpenStreetMap. Thanks @dimqua
  - [Mapillary](https://www.mapillary.com/app/) - **14-eyes** - Crowdsourced street-level imagery built on top of OpenStreetMap. Open source. Includes map data generated with object recognition software. Coverage is lacking in many cities but can always be improved upon.
  - *Editor note: I've seen OsmAnd: it's a mobile app. I've seen HERE WeGo: It's on malvertising filter lists.*
- Transit
  - [Transportr](https://transportr.app/) An open-source Transit app on Android that takes information from several providers (e.g Deutsche Bahn in Germany) and enables you to use them in the app. Visualises the routes on an online OpenStreetMap map. Works in most of Western-Europe, as well as the USA, Australia, Canada, New Zealand, Brazil, Nicaragua, Costa Rica, the UAE and Ghana.
  **Beware: most information-providers only have beta or alpha support, it may be a good idea to keep a second app as a fallback option**
- Trends
  - *Help requested!*

## Operating systems

- Android/Fuchsia
  - *Note: You'll either need a rooted device with an unlocked bootloader, or a specific device depending on which OS you like.*
  - [Ubuntu Touch](https://ubuntu-touch.io/) - Ubuntu, but for phones.
  - [LineageOS](https://www.lineageos.org/) **5-eyes** - Open-source and based on Android, but without the crap.
  - [SailfishOS](https://sailfishos.org/) - *Help requested!*
  - ~~[CopperheadOS](https://copperhead.co/android/) - **5-eyes** - A "secure" version of Android from Canada.~~
    - u/poto-tomato pointed out that CopperheadOS is [no longer active](https://old.reddit.com/r/CopperheadOS/comments/8qdnn3/goodbye/). It has now evolved into a [new project](https://old.reddit.com/r/CopperheadOS/comments/b6muvh/androidhardening_project_renamed_to_grapheneos/) under the name [GrapheneOS](https://github.com/GrapheneOS).
  - [postmarketOS](https://postmarketos.org/) - Open-source mobile Linux OS. Can install different user interfaces such as [Plasma Mobile](https://www.plasma-mobile.org/). Thanks @okias
  - [Replicant](https://replicant.us/) - **5-eyes** - Free Android distribution. Puts the emphasis on "freedom and privacy/security".
  - Note: Please see Issue #55 for details on /e/.
- Chrome OS
  - [Qubes OS](https://www.qubes-os.org/) - "A reasonably secure operating system", at least according to their website. Edward Snowden recommends it.
  - [Subgraph OS](https://subgraph.com/index.en.html) - A desktop computing and communications platform that is designed to be resistant to network-borne exploit and malware attacks.
  - [Tails](https://tails.boum.org/) - For the uber-paranoid. Runs live and the entire OS is routed through Tor right from boot. Built on Debian.
  - [Knoppix](http://www.knopper.net/knoppix/index-en.html) - Another Live OS, runs from CD/DVD/USB. Can also be installed if desired.
  - [Parrot OS](https://parrotsec.org/) - Debian-based and privacy focused. Fully sandboxed. (thanks u/Safe_Airport)
  - [PureOS](https://pureos.net/) - **5-eyes** - The OS of Purism Laptops (mentioned in the Hardware section). Very clean UI. *Editor note: I could not get this working on a UEFI Dell laptop. The group behind PureOS does not provide any UEFI support.*
  - Any other form of Linux should work fine too.
    - [Ubuntu](https://www.ubuntu.com/)
    - [Debian](https://www.debian.org/)
    - [Mint](https://linuxmint.com/)
    - [Fedora](https://getfedora.org/)
    - [Arch](https://www.archlinux.org/) or [Manjaro](https://manjaro.org/) (Manjaro is objectively much easier to get running than Arch)
    - [Trisquel](https://trisquel.info/), [Gentoo](https://www.gentoo.org/), and [Alpine](https://www.alpinelinux.org/) (thanks u/privacyfreak555)
    - [etc etc etc](https://en.wikipedia.org/wiki/List_of_Linux_distributions)
- Wear OS
  - [AsteroidOS](https://asteroidos.org/) - **14-eyes** - The cleanest (and only) open-source alternative for Wear OS. Make sure you buy a watch that supports it!
- Android Auto
  - *Help requested!*
- Google TV/Android TV
  - [Kodi](https://kodi.tv/) - It's incredibly powerful and backed by one of the strongest communities around. Tons of plugins to do nearly anything you want. Software installs on nearly any platform.
  - [OSMC](https://osmc.tv/) - Free, open source media center OS. Kodi is pre-installed. Thanks to @g4rret and @lgiard for clarifying the difference between Kodi and OSMC!

## Desktop applications

- Chrome
  - [Ungoogled Chromium](https://github.com/Eloston/ungoogled-chromium) - Chromium (which Chrome and countless other browsers are built on top of) is one of the cleanest and light-weight browsers available. This version cuts out all the Google crap.
  - [Firefox](https://firefox.com/) - Built by Mozilla. Huge extension library; great for privacy.
  - [Waterfox](https://www.waterfox.net/) - **5-eyes** - Based on Firefox, but **64-bit only** with an emphasis on speed and privacy. Has a "classic" version built off older Firefox for legacy extension support and also an "alpha" version built off Quantum. It doesn't collect any telemetry and also removes Pocket from the alpha release. Project is run by [Alex Kontos](https://github.com/MrAlex94/) and is constantly in active development. Looks very clean and fast. Android versions are in the works too. **UPDATE:** @Nudin pointed out in Issue #85 that Waterfox is now [apart of System1](https://www.waterfox.net/blog/waterfox-has-joined-system1/).
  - [Vivaldi](https://vivaldi.com/) - Privacy-focused browser. Appears to be very customizable and feature-rich.
  - [Tor Browser](https://www.torproject.org/download/) - Firefox-based browser routed through the onion network. Automatically has a few privacy extensions installed (such as HTTPS Everywhere). Be careful using it in public though, as it *can* look like a pretty suspicious piece of software. Available for Windows, Linux, macOS, and Android.
- Earth
  - Different from Maps Satellite in the sense that Earth has tons of complex features that require desktop software to be installed.
  - [KDE Marble](https://kde.org/applications/education/org.kde.marble) - Strong alternative for G Earth. Currently only on Linux, but is being ported to other platforms. Thanks to @PopeRigby
- Android Studio (not specifically for Android development, just in general)
  - [VSCodium](https://github.com/VSCodium/vscodium) - VSCodium is VSCode but without all the Microsoft telemetry and branding.
  - Text editors:
    - [Vim](https://www.vim.org/) - Open-source text editor. Thanks @moon-chilled
    - [Emacs](https://www.gnu.org/software/emacs/) - Another open-source text editor. Thanks @moon-chilled

## Mobile applications (mobile apps installable from stores)

When searching for replacements, check the alternative stores (such as F-Droid) before checking the Play Store.

- Play Store
  - [F-Droid](https://f-droid.org/) - Catalogue of FOSS apps for Android. Easy to install and keeps track of updates. Also has a browser version if you don't want to install the app.
  - [Aptoide](https://www.aptoide.com/) - Marketplace for Android apps. Publishers/developers manage their own stores rather than a centralized market such as Google Play Store.
  - [Yalp Store](https://github.com/yeriomin/YalpStore) - Yalp downloads Play Store apps as APK files. Helpful if you want to stay away from the Play Store, but require an app that is only available there.
  - [APKMirror](https://www.apkmirror.com/) - An online library of user-uploaded APK files. Helpful if you need a specific older version of an app or don't want to download it through Google Play.
  - [Aurora Store](https://gitlab.com/AuroraOSS/AuroraStore) - Aurora Store is ~~simply a fork of the Yalp Store~~ no longer a fork of Yalp, but is now its own project (see their [readme](https://gitlab.com/AuroraOSS/AuroraStore/blob/master/README.md)). **Update:** Removed note on using microG as Aurora Store [does not use it](https://gitlab.com/AuroraOSS/AuroraStore/-/blob/master/README.md#L77). Thanks @RefexHD & @notpushkin
  - [Fossdroid](https://fossdroid.com/) - Uses the same library as F-Droid, but with a modern UI similar to that of the Play Store and the ability to view apps by popularity.
  - [G-Droid](https://gitlab.com/gdroid/gdroidclient/) - Also uses the F-Droid repo but with a different UI.
  - [APKGrabber](https://github.com/hemker/apkgrabber) - Fork of [APKUpdater](https://github.com/rumboalla/apkupdater). Both are great tools for avoiding app stores (on Android).
  - [Aurora Droid](https://forum.xda-developers.com/android/apps-games/app-aurora-droid-fdroid-client-t3932663) - Yet another F-Droid client, potentially has a few bugs (thanks u/OfficialJohnGL4)
- Chrome (Android)
  - [Fennec F-Droid](https://f-droid.org/en/packages/org.mozilla.fennec_fdroid/) - A privacy-focused version of Firefox Android available on F-Droid. It's focused on removing any proprietary bits found in official Mozilla's builds. (thanks u/SupremeLisper)
  - [Bromite](https://www.bromite.org/) - Privacy-focused/open-source build of Chromium with built-in ad blocking. (thanks u/SupremeLisper)
- Calculator
  - [Simple Calculator](https://github.com/SimpleMobileTools/Simple-Calculator) - Also part of the SMT project. Available on F-Droid.
  - [Calculator N+](https://github.com/tranleduy2000/ncalc) (or NCalc+) - Open-source feature-rich calculator. App itself is no longer in development, but the developer does [encourage pull requests](https://github.com/tranleduy2000/ncalc#calculator-n---powerful-calculator-for-android). I've used it frequently and it works great. Not on F-Droid, but a 3rd party play store can probably find it; or the APK's are available as releases on GitHub. You can also compile from source.
- Calendar
  - [Fruux (mobile app)](https://fruux.com/) - Same service from above provides an Android app.
  - [Etar](https://github.com/xsoh/Etar-Calendar) - Open-source material design Calendar that integrates with the Android Calendar API. If you have a CalDAV/CardDAV server, I recommend using [DAVx5](https://www.davx5.com/) to sync with it. Available from F-Droid. Also look at [ICSx5](https://icsx5.bitfire.at/), another WebDav/CalDav client that can integrate with calendar apps. Also available from F-Droid. Thanks @je-vv for ICSx5.
- Camera
  - [Open Camera](https://opencamera.sourceforge.io/) - Open source camera for Android. Thanks @je-vv
- Clock
  - [Clock +](https://github.com/philliphsu/ClockPlus) - Open-source Alarm clock, timer, and stop watch. Available from F-Droid.
  - [Simple Alarm Clock](https://github.com/yuriykulikov/AlarmClock) - Exactly as it's name says; simple alarm clock yet adds many improvements over other apps. No dock mode or world clock.
  - [Insane Alarm!](https://github.com/RIAEvangelist/insane-alarm) - Developer states that he had "spent a night out with the boys and drank a bit too much but needed to be up in the morning". So, he made the loudest alarm clock possible based off an emergency alarm from when he was in the military. This app doesn't mess around, use it wisely.
- Contacts
  - [Fruux (mobile app)](https://fruux.com/) - Fruux *also* provides a contacts app.
  - [Simple Contacts](https://github.com/SimpleMobileTools/Simple-Contacts) - Open-source. Part of the [Simple Mobile Tools](https://github.com/SimpleMobileTools) project. Available from F-Droid.
  - [Open Contacts](https://f-droid.org/en/packages/opencontacts.open.com.opencontacts/) - Available from F-Droid. (thanks u/consentio)
- Android Messages (specifically SMS, not IM)
  - [QKSMS](https://github.com/moezbhatti/qksms) - Open-source. Very clean and feature rich SMS app.
  - [Silence.im](https://silence.im/) - Open-source and utilizes Signal's encryption protocol. Seamlessly works with SMS. End-to-end encryption with other Silence users.
  - *Both Messages replacements are available on F-Droid*
- Gboard
  - [AnySoftKeyboard](https://anysoftkeyboard.github.io/) - Open-source keyboard. Available on F-Droid.
  - [Hacker's Keyboard](https://github.com/klausw/hackerskeyboard) - Also open-source. Very useful for developers or sysadmins on the go.
  - [kboard](https://github.com/adgad/kboard) - Open-source. Has features for phrases, "lenny faces", macros and more.
  - [Simple Keyboard](https://github.com/rkkr/simple-keyboard) - Open-source, available from F-Droid.
  - [Indic Keyboard](https://gitlab.com/indicproject/indic-keyboard) - Open-source keyboard that supports many languages that other keyboards sometimes don't support. Not on F-Droid, but can be built from source or possibly through a Play Store alternative.
  - [OpenBoard](https://github.com/dslul/openboard) - New 100% FOSS keyboard, based on AOSP. Similar to "Simple Keyboard". Thanks @Glitchy-Tozier
- Drive
  - [ownCloud Android](https://github.com/owncloud/android) - ownCloud Android client.
  - [Nextcloud Android](https://github.com/nextcloud/android) - Nextcloud Android client.
  - [Syncthing Android](https://github.com/syncthing/syncthing-android) - Wrapper of Syncthing for Android
  - *All Drive replacements are available on F-Droid*
- Gmail
  - [Protonmail](https://protonmail.com/support/knowledge-base/android/) - Can be downloaded from the Play Store, but may work with one of the store replacements above (such as Yalp).
  - [Tutanota](https://f-droid.org/en/packages/de.tutao.tutanota/) - **14-eyes** - Client available from F-Droid.
  - Posteo - Any **open-source mail client** such as: [K-9 Mail](https://k9mail.github.io/) and [FairEmail](https://email.faircode.eu/). Both are available on F-Droid.
  - [Zoho Mail](https://www.zoho.com/mail/ios-android-apps.html) - Also on the Play Store but other stores may work too.
  - Mailbox.org - Mailbox.org provides IMAP settings for Android/iOS and an iOS profile. Thanks @avasts Issue #45
  - [Disroot](https://f-droid.org/en/packages/org.disroot.disrootapp/) - Available from F-Droid.
- Keep (or any stock note-taking app)
  - [Notepad](https://github.com/farmerbb/Notepad) - Open-source and available from F-Droid. Supports Markdown and HTML. Very clean and feature-rich. *Offline only*.
  - [Joplin](https://github.com/laurent22/joplin) for Android - Scroll down on the GitHub page until you reach the Android download links. No F-Droid repo, but you can download the APK directly instead of using the Play Store.
  - [Standard Notes](https://standardnotes.org/) - Encrypted note storage with loads of features.
  - [Omni Notes](https://omninotes.app/) - Very feature rich, open-source, material design notes app. Very active development. Available on F-Droid.
  - [Carnet](https://github.com/PhieF/CarnetDocumentation) - I had some trouble finding info on this one. Looks like it has pretty seamless/painless ownCloud and NextCloud integration. Also available on F-Droid.
  - [Markor](https://gsantner.net/project/markor.html) - Open-source notes/to-do app for Android. Supports Markdown editing. Available on F-Droid. App is 100% offline, as stated on the [GitHub README](https://github.com/gsantner/markor#privacy).
  - [Orgzly](http://orgzly.com/) Open-source and available from F-Droid. Notes are stored in the plain-text [Org mode](https://orgmode.org/) format. Supports searching, metadata, and manual sync with Dropbox or local directory, which can be synced using e.g. Syncthing.
- Maps/Waze
  - Don't use Waze. It's owned by Google.
  - [Maps](https://f-droid.org/en/packages/com.github.axet.maps/) - Available from F-Droid. Open-source navigation app based on MAPS.ME. Searching for addresses doesn't always work and finding businesses can be a slight hassle, but overall one of the better apps I've used.
  - [OsmAnd](https://osmand.net/) - OpenStreetMap for Android. (thanks u/masao77)
    - As OsmAnd is primarily crowdsourced, many regions may not be totally accurate. If you would like to help improve OpenStreetMap and OsmAnd, check out [StreetComplete](https://wiki.openstreetmap.org/wiki/StreetComplete). It is available from [F-Droid](https://f-droid.org/en/packages/de.westnordost.streetcomplete/).
  - [Transportr](https://transportr.app/) - Primarily European, this is an open-source public transport app. Thanks to @lgiard
  - [Offi or Oeffi](https://oeffi.schildbach.de/) - Another recommendation from @lgiard, this app is also for public transport.
- News
  - [Flym](https://github.com/FredJul/Flym) - Open-source Material Design RSS reader. Available from F-Droid.
- Photos
  - [Piwigo Android](https://github.com/Piwigo/Piwigo-Android) - You need to have Piwigo set up first.
- Pay
  - *Help requested!*
  - Note: Realistically, there most likely is not a privacy friendly alternative to Google Pay. Get a wallet with RFID protection and keep your cards with you.
- YouTube
  - [NewPipe](https://newpipe.schabi.org/) - Powerful open-source YouTube alternative available from F-Droid. Supports audio only; background playback; picture-in-picture; no ads.
  - [FreeTube](https://github.com/FreeTubeApp/FreeTube) - Open-source YouTube client that uses the Invidio.us API to serve content. Not on F-Droid, but you can download the APK from GitHub. (thanks u/wesaphzt)
  - [YouTube Vanced](https://forum.xda-developers.com/android/apps-games/app-youtube-vanced-edition-t3758757) (if you are desperate) - Please read the XDA post before deciding to use this.
- Authenticator
  - [andOTP](https://github.com/andOTP/andOTP) - Open-source 2FA app available from F-Droid.
  - [FreeOTP+](https://github.com/helloworld1/FreeOTPPlus) - FreeOTP is no longer in development so this fork should be used instead as it is currently in development. Available from F-Droid.
  - [Aegis](https://github.com/beemdevelopment/Aegis) - Open-source 2FA for Android. Available on F-Droid.
  - [Authenticator](https://mattrubin.me/authenticator/) - **iOS** - Open-source 2FA for iOS. (thanks u/SomeoneWannaBe)
  - [Tofu](https://tofuauth.com) - **iOS** - Open-source 2FA for iOS.
- Play Music/Play Movies & TV
  - [Audinaut](https://github.com/nvllsvm/Audinaut) - An open-source Airsonic client for Android. Available from F-Droid.
  - [MALP](https://gitlab.com/gateship-one/malp) - An open-source Android client for MPD. Available on F-Droid.
- Hangouts
  - [Keybase](https://keybase.io/) - **5-eyes** - encrypted chat like Signal with features like Slack. Does not require a phone number to sign up. Also has file storage. **Note:** Keybase was acquired by Zoom, Inc. in May 2020 ([Keybase blog](https://keybase.io/blog/keybase-joins-zoom), [Zoom blog](https://blog.zoom.us/wordpress/2020/05/07/zoom-acquires-keybase-and-announces-goal-of-developing-the-most-broadly-used-enterprise-end-to-end-encryption-offering/)). Thanks @notpushkin & @multimob.
  - [Conversations](https://conversations.im/) - **14-eyes** - An open-source Android Jabber/XMPP client. It's a paid app on Google Play, but you can also [build it from source](https://github.com/siacs/Conversations) for free if you want to.
  - [Riot](https://github.com/vector-im/riot-android) **5-eyes** - Android app - The open-source Android client for Riot.
  - [Jitsi Meet (F-Droid)](https://f-droid.org/en/packages/org.jitsi.meet/) - Jitsi is an open-source secure video conferencing platform. No account is needed to use it, simply enter a Room Name to join or host a meeting. The host is able to kick rogue users from the call. Works directly in your browser, with apps available for iOS and Android. It is not necessary to self-host, but self-hosting is an option for those who wish to. Very low latency and easy to set up. A free public server is available at (https://meet.jit.si) (**5-eyes** server)
- Assistant
  - [Mycroft Android](https://github.com/MycroftAI/Mycroft-Android) - Android client for Mycroft. Must be built in IDE; no pre-built binaries are available.
  - [Ara](https://github.com/FultonBrowne/Ara-android) - Open-source virtual assistant for Android. Can replace Google Assistant (home button functionality) on most devices. Either uses the authors server by default, or you can [run your own server](https://github.com/FultonBrowne/Ara-Server). Thanks @FultonBrowne (author of Ara)
- Play Services Framework
  - [microG](https://microg.org/) - A re-implementation of Google’s proprietary Android user space apps and libraries. It allows to use more precise navigation (which is proprietary in standard Android ROMs) and optionally receive push messages (requires connection to Google's servers, but also supports routing this connection through Tor). Thanks @notpushkin
- *Other*
  - [Blokada](https://blokada.org/) - From the website: "If you want to efficiently block ads, trackers, malware, save on your data plan, speed up your device and protect your privacy with just one application, then Blokada is for you. It is free, secure and open source." Uses internal VPN on Android to block ads. [Available from F-Droid](https://f-droid.org/packages/org.blokada.alarm/).

**Android launchers**:

- [Shade Launcher](https://github.com/amirzaidi/Shade) - Open-source Android launcher styled after the Google Pixel launcher. No F-Droid, but you can download the APK from GitHub.
- [ZimLX](https://github.com/otakuhqz/ZimLX) - Open-source launcher. Active development with lots of nice features. Available from F-Droid.
- [Lawnchair](https://lawnchair.app/) - Another open-source launcher, also built to look similar to Google's launcher (it is built off AOSP Launcher3). Available from F-Droid and also APKMirror. (thanks u/droidonomy)

## Hardware

- Nexus/Pixel
  - [This list](https://www.oneclickroot.com/rootable/) shows compatibility for rooting Android devices.
  - [Purism Librem 5](https://puri.sm/products/librem-5/) - **5-eyes** - From the company that makes Purism laptops. Runs PureOS. Thanks @brandonnodnarb
- Chromebook
  - Literally any other laptop with some form of Linux, *or*
  - [TUXEDO](https://www.tuxedocomputers.com/) - **14-eyes** - Privacy-focused laptop maker out of Germany. Tech specs are very competent and can easily compete with other modern systems. Fully Linux compatible. They also offer desktops. (thanks u/itsec_ho)
  - [Purism Laptops](https://puri.sm/) - **5-eyes** - Privacy-focused laptop running PureOS. Good designs and decent hardware.
  - [Pinebook Pro](https://www.pine64.org/pinebook-pro/) - Mid-range Linux/FreeBSD alternative to Chromebook.
- Chromecast
  - [Microsoft less HDMI adapter](https://www.microsoft.com/accessories/en-us/products/adapters/wireless-display-adapter-2/p3q-00001) - **5-eyes** - The **only** reason I'm recommending this Microsoft product is because there is no possible way for it to extract any data and ship it off to Microsoft. If someone finds proof that it *can*, I will remove it.
- Google Home
  - [Mycroft](https://mycroft.ai/) - **5-eyes** - Open-source virtual personal assistant. Can be run on a Raspberry Pi. (thanks u/Kentto7)
  - [Home Assistant](https://www.home-assistant.io/) - Open-source home automation. (thanks u/bilange)
- FitBit
  - *Due to Google's  [recent acquisition of FitBit](https://outline.com/tsJCYN), it is recommended to avoid using FitBit. Instead, check out this [list of smart watches](https://asteroidos.org/install/) supported by Asteroid OS (See Wear OS in [Operating systems](#operating-systems)). Thanks @ribtoks*

# Useful links, tools, and advice

## Resources

Everything you need to become a Privacy Wizard.

- [Privacy Tools](https://www.privacytools.io/) (thanks u/yieldingTemporarily)
- [ethical.net](https://ethical.net/) (thanks u/yieldingTemporarily)
- [AlternativeTo](https://alternativeto.net/) - Find alternatives for software. Used extensively to build this guide. Also check out [Switching.software](https://switching.software/) (thanks @mynamesleon)
- [Framasoft](https://framasoft.org/en/) - Lots of alternatives and software. Too many to fit into the list. Also check out [this link](https://degooglisons-internet.org/en/). Thanks @NicolasPA
- [r/Privacy wiki](https://old.reddit.com/r/privacy/wiki/index)
- [r/VPN](https://old.reddit.com/r/VPN/) - Read the sidebar and [wiki](https://old.reddit.com/r/VPN/wiki/index) to learn more about why you should consider using a VPN. I personally use [Mullvad](https://mullvad.net) but do your own research before choosing.
- [Four Methods to Create a Secure Password You'll Actually Remember](https://outline.com/XuMTFA)
- [How to Create a Strong Password (and Remember It)](https://outline.com/dqfuqL)
- Use a [password manager](https://outline.com/NC69FD) such as [Bitwarden](https://bitwarden.com)
- Set up [multi-factor/two-factor authentication](https://en.wikipedia.org/wiki/Multi-factor_authentication) on as many accounts as you can
- Don't save passwords to your browser: [Erase the entire password cache](http://www.wikihow.com/Delete-Remembered-Passwords) once you set up a password manager.
- [Remove bloatware from Android (without root)](https://www.xda-developers.com/uninstall-carrier-oem-bloatware-without-root-access/)
- [What are 5-eyes, 9-eyes, and 14-eyes?](https://restoreprivacy.com/5-eyes-9-eyes-14-eyes/)
- [Outline](https://outline.com/) is an awesome tool for getting all the junk out of news articles (I've used it a few times in this guide already). Sometimes it can get around paywalls for "premium" news sites.
- [What is Tor and should I use it?](https://outline.com/JRCscH)
- [HTTP vs. HTTPS](https://outline.com/xUXZMh)
- The EFF has an [excellent guide](https://ssd.eff.org/) on how to stay safe and secure online. It is incredibly useful and I suggest that everyone read through it.
- Click [here](https://www.thewindowsclub.com/windows-10-telemetry) and [here](https://winaero.com/blog/how-to-disable-telemetry-and-data-collection-in-windows-10/) for tips on disabling Windows 10 telemetry/data collection.
- Click [here](https://duckduckgo.com/newsletter) to sign up for DuckDuckGo's privacy newsletter, and [here](https://spreadprivacy.com/) for more tips, articles, and blog posts from DuckDuckGo.
- [Delete Facebook](https://deletefacebook.com/). Another guide can be found [here](https://www.wikihow.com/Permanently-Delete-a-Facebook-Account).
- [Why you should put tape over your webcam](https://outline.com/fYCu98)
- [What is DNS and why should I change it?](https://outline.com/8jsWXw) I think it's common sense to not use Google Public DNS; I use and recommend [Cloudflare's 1.1.1.1](https://1.1.1.1/). Use [DNSPerf](https://www.dnsperf.com/#!dns-resolvers) to see which one is fastest for you (Google ranks 4th and Cloudflare ranks 1st at time of writing this).
- What is GDPR? [TechRadar](https://outline.com/6sjd76) and [The Guardian](https://outline.com/exmSpf)
- [Here](https://github.com/lfit/itpol/blob/master/linux-workstation-security.md) is a really good guide for configuring a super secure Linux workstation (thanks u/aoeudhtns)
- [A website to raise awareness of online privacy](https://theytrackyou.com/). Lot's of good tips in here (thanks u/brais33)
- [Android Privacy Guide](https://gitlab.com/Attedz/AndroidPrivacyGuide) (thanks u/rightknobhead)
- [Windows 10 Privacy Guide](https://fdossena.com/?p=w10debotnet/index_1903.frag) (thanks again u/rightknobhead)
- Check out [Prism Break](https://prism-break.org/en/) (thanks u/FrontierPsycho)
- [Guide for Linux users](https://github.com/wesaphzt/block-all-google) on blocking everything Google at the network level. This can and probably will break other alternatives that rely on Google to serve content. Thanks u/wesaphzt
- u/wesaphzt also provided [this](https://github.com/pyllyukko/user.js), [this](https://ffprofile.com/), and [this](https://www.privacytools.io/browsers/#about_config) for hardening Firefox.
- Check out [WindowsSpyBlocker](https://github.com/crazy-max/WindowsSpyBlocker) and [this tutorial](https://github.com/adolfintel/Windows10-Privacy) for even more Windows 10 tips (thanks u/rudolf323)
- Did you read the [wiki](https://old.reddit.com/r/privacy/wiki/index) yet? Go do that.

## Books

- [Edward Snowden - Permanent Record (Autobiography)](https://www.goodreads.com/book/show/46223297-permanent-record)
- [Jaron Lanier - Ten arguments for deleting your social media accounts right now](http://www.jaronlanier.com/tenarguments.html) (2018)
- [Shoshana Zuboff - The age of surveillance capitalism: The fight for a human future at the new frontier of power](https://www.publicaffairsbooks.com/titles/shoshana-zuboff/the-age-of-surveillance-capitalism/9781610395694/) (2019)
- [Tim Wu - The Attention Merchants: a revelatory, ambitious and urgent account of how the capture and re-sale of human attention became the defining industry of our time.](http://www.timwu.org/AttentionMerchants.html) (2017)
  - [Review from The Guardian](https://www.theguardian.com/books/2016/dec/26/the-attention-merchants-tim-wu-review)
- [Roger McNamee - The story of how a noted tech venture capitalist, an early mentor to Mark Zuckerberg and investor in his company, woke up to the serious damage Facebook was doing to our society and set out to try to stop it.](https://www.zuckedbook.com/) (2019)

## Blog posts

- [Electronic Frontier Foundation - Blog 2018-11-01: Google Chrome’s users take a back seat to its bottom line](https://www.eff.org/deeplinks/2018/11/google-chromes-users-take-back-seat-its-bottom-line)
- [J. Nathan Matias - Blog 2018-12-08: Quitting Facebook & Google](https://medium.com/@natematias/https-medium-com-natematias-quitting-facebook-google-aaf8f4c80fbf)
- [Marko Saric - Blog 2019-12-05: How to fight back against Google AMP as a web user and a web developer](https://markosaric.com/google-amp/)
- Click [here](https://www.mozilla.org/en-US/internet-health/privacy-security/) and [here](https://blog.mozilla.org/internetcitizen/2017/01/30/15-privacy-tips-protect-online-life/) for tips from the Mozilla Foundation on internet privacy and security.

## News articles

- [Forbes - 2012-05-15: Google can survive too much innovation. You can’t.](https://www.forbes.com/sites/forbesleadershipforum/2012/05/15/google-can-survive-too-much-innovation-you-cant/#37ff02f66003)
- [Business Insider - 2015-04-17: The truth about Google’s famous ’20% time’ policy](https://www.businessinsider.com/google-20-percent-time-policy-2015-4)
- [The Atlantic - 2016-11-01: The binge breaker](https://www.theatlantic.com/magazine/archive/2016/11/the-binge-breaker/501122/)
- [WIRED - 2017-09-22: How malware keeps sneaking past Google Play’s defenses](https://www.wired.com/story/google-play-store-malware/)
- [MIT Technology Review - 2017-10-03: Forget killer robots - bias is the real AI danger](https://www.technologyreview.com/s/608986/forget-killer-robotsbias-is-the-real-ai-danger/)
- [Business Insider - 2018-01-08: Google managers kept blacklists of conservative employees and one manager considered holding ‘trials,’ a new lawsuit alleges](https://www.businessinsider.com/conservative-google-employees-are-blacklisted-lawsuit-alleges-2018-1)
- [CNBC - 2018-01-24: A longtime Google engineer quits, saying the company is now ‘100% competitor-focused’](https://www.cnbc.com/2018/01/24/google-engineer-steve-yege-calls-company-100-percent-competitor-focused.html)
- [Washington Post - 2018-01-26: Facebook and Google are doomed, George Soros says](https://www.washingtonpost.com/news/the-switch/wp/2018/01/26/facebook-and-google-are-doomed-george-soros-says/)
- [Gizmodo - 2018-03-26: Google isn’t listening, so its employees are suing](https://gizmodo.com/google-isnt-listening-so-its-employees-are-suing-1823611720)
- [The Guardian - 2018-03-28: Google sees major claims of harassment and discrimination as lawsuits proceed](https://www.theguardian.com/technology/2018/mar/28/google-sexual-harassment-pay-gap-lawsuits-proceed)
- [CNBC - 2018-05-11: How to stop Google from tracking everything you do online](https://www.cnbc.com/2018/05/11/how-to-stop-google-from-tracking-me-online.html)
- [Engadget - 2018-05-24: Google will always do evil](https://www.engadget.com/2018/05/24/google-will-always-do-evil/)
- [TechCrunch - 2018-06-07: Google’s new ‘AI principles’ forbid its use in weapons and human rights violations](https://techcrunch.com/2018/06/07/googles-new-ai-principles-forbid-its-use-in-weapons-and-human-rights-violations/)
- [The Intercept - 2018-08-01: Google plans to launch censored search engine in China, leaked documents reveal](https://theintercept.com/2018/08/01/google-china-search-engine-censorship/)
- [Washington Post - 2018-08-09: Opinion - Google’s China plan isn’t just evil - it’s bad for business](https://www.washingtonpost.com/opinions/global-opinions/googles-china-plan-isnt-just-evil--its-bad-for-business/2018/08/09/143046be-9c12-11e8-8d5e-c6c594024954_story.html)
- [The New York Times - 2018-10-25: How Google protected Andy Rubin, the ‘Father of Android’](https://www.nytimes.com/2018/10/25/technology/google-sexual-harassment-andy-rubin.html)
- [WIRED - 2018-12-10: A new Google+ blunder exposed data from 52.5 million users](https://www.wired.com/story/google-plus-bug-52-million-users-data-exposed/)
- [WIRED - 2019-08-13: Three years of misery inside Google, the happiest company in tech](https://www.wired.com/story/inside-google-three-years-misery-happiest-company-tech/)
- [TechCrunch - 2020-01-23: Google’s latest user-hostile design change makes ads and search results look identical](https://techcrunch.com/2020/01/23/squint-and-youll-click-it/)
- [The New York Times - 2020-01-24: You are now remotely controlled](https://www.nytimes.com/2020/01/24/opinion/sunday/surveillance-capitalism.html)

# The lighter side

- Movies and TV I recommend:
  - *Snowden (2016)* - Based on the true story of Edward Snowden, the CIA/NSA/etc whistleblower. Directed by Oliver Stone.
  - *Deep Web (2015)* - Documentary (narrated by Keanu Reeves) about Ross Ulbricht aka. Dread Pirate Roberts and the infamous "Silk Road" dark market. Directed by Alex Winter.
  - *Mr. Robot* - Hacker-drama starring Rami Malek. Producers hired actual hackers as consultants to ensure the show is as accurate as possible; real-world tools used in the show.
  - *Silicon Valley* - Satirical tech comedy about a compression startup struggling to take off in Silicon Valley, California.
- Podcasts:
  - [Darknet Diaries](https://darknetdiaries.com/) (by Jack Rhysider) - Highlights real-life hackers and their stories. Covers privacy topics a fair bit.
  - The WAN Show (Linus Tech Tips) - Not specifically privacy, but they cover all sorts of tech news.
  - [The Privacy, Security, & OSINT Show](https://inteltechniques.com/podcast.html) - "This weekly podcast presents ideas to help you become digitally invisible, stay secure from cyber threats, and make you a better online investigator."
  - [Security Now!](https://www.grc.com/SecurityNow.htm) - "TechTV's Leo Laporte and I spend somewhat shy of two hours each week to discuss important issues of personal computer security." (Thanks u/Abaddon182)
- Other:
  - [xkcd](https://xkcd.com/) - They have comics for *everything*.
  - System32 Comics [Instagram](https://www.instagram.com/system32comics/) and [Reddit](https://www.reddit.com/r/System32Comics/) - Comedic computer comics.

# Closing remarks

It's a shame that Google, with their immense resources, power, and influence, don't see the benefits of helping people secure themselves online. Instead, they force people like us to scour the web for alternatives and convince our friends and family to do the same, while they sell off our data to the highest bidder.

Hopefully this guide can serve as a starting point for those new to privacy, or be a good refresher for the experts.

Good luck and stay safe!
